@@ -7,8 +7,8 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 58),
-    __version__='0.15.58',
+    version_info=(0, 15, 64),
+    __version__='0.15.64',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -60,9 +60,8 @@ _package_data = dict(
         'Topic :: Text Processing :: Markup',
     ],
     keywords='yaml 1.2 parser round-trip preserve quotes order config',
-    windows_wheels=True,
+    wheels=dict(windows='appveyor', linux='libyaml-devel', macos='builder@macos'),
     read_the_docs='yaml',
-    many_linux='libyaml-devel',
     supported=[(2, 7), (3, 4)],  # minimum
     tox=dict(
         env='*pn',  # also test narrow Python 2.7.15 for unicode patterns
